function love.load()

    local fullscreen, fstype = true, "desktop"
    love.window.setFullscreen(fullscreen, fstype)

    love.graphics.setDefaultFilter("nearest","nearest") --high res scaling

    love.graphics.setBackgroundColor(0.5,0.5,0.5)
    local font = love.graphics.newFont("/fonts/Dear Santa.ttf", 64)
    love.graphics.setFont(font)
    require 'player'
    require 'gamestates'
    require 'ground'
    require 'sky'
    require 'city1'
    require 'city2'
    require 'decoration'
    require 'birds'
    require 'redbird'
    require 'coin'
    require 'adplane'
    require '/libraries/tesound'

    newGameState("Menu")
    ground.spawn(0,200)
    ground.spawn(1920,200)
    sky.spawn(0,25)
    sky.spawn(1920,25)
    city1.spawn(0,100)
    city1.spawn(1920,100)
    city2.spawn(0,50)
    city2.spawn(1920,50)
    decoration.spawn(2180, 200)

    scoretimer=0
    score=0
    coinsCollected=0
    retrytimer=0

    if not(love.filesystem.exists("data.txt"))then
        local ScoreData={0,0}
        love.filesystem.write("data.txt", table.concat(ScoreData,"\n"))
    end
    local highscores={}
    for line in love.filesystem.lines("data.txt") do
        table.insert(highscores, tonumber(line))
    end
    bestscore=highscores[1]
    coins=highscores[2]
end

function love.update(dt) --Game's core
    TEsound.cleanup()
    FPS = love.timer.getFPS()

    ground.update(dt)
    sky.update(dt)
    city1.update(dt)
    city2.update(dt)
    decoration.update(dt)
    birds.update(dt)
    redbird.update(dt)
    coin.update(dt)
    adplane.update(dt)


    if GameState == "Play" then --execute at play
        Player.update(dt)
        scoretimer = scoretimer + dt
        score = math.floor(scoretimer)
    end
    if GameState == "Death" then
        retrytimer = retrytimer + dt
    end
end

function love.draw() --Game's graphics
    
    sky.draw()
    adplane.draw()
    city2.draw()
    city1.draw()
    decoration.draw()
    coin.draw()
    birds.draw()
    redbird.draw()
    ground.draw()
    MenusDraw()

    if GameState == "Play" then --execute at play
        Player.draw()
        love.graphics.print("Seconds: "..score, 600, 30, nil, 0.5)
        love.graphics.draw(coin.spriteChosen, 1000, 40, nil, nil, nil, 24.5, 24.5)
        love.graphics.print("x"..coinsCollected, 1025, 30, nil, 0.5)
    end
    love.graphics.print("FPS:"..FPS, 10, 30, nil, 0.5)
end

--vvv Game's inputs vvv---



function love.keypressed(key, scancode, isrepeat)
    if key == "f11" then
        fullscreen = not fullscreen
        love.window.setFullscreen(fullscreen, fstype)
    end

    if key == "f5" then
        bestscore=0
        coins=0
        local ScoreData={bestscore,coins}
        love.filesystem.write("data.txt", table.concat(ScoreData,"\n"))
    end
end

function love.mousepressed(x,y, button, istouch, presses)
    
    if GameState == "Menu" and button == 1 then
        newGameState("Play")
    end

    if GameState == "Play" then
        if button == 1 and Player.y > 50 then
            Jump(Player.jumpforce)
        end
        if button == 2 then
            TEsound.play("/sounds/slowfall.wav","static")
        end
    end

    if GameState == "Death" and button == 1 and retrytimer >= 2  then
        newGameState("Menu")
        retrytimer = 0
    end
end



---vvv custom utilities vvv---

function saveScore()
    local ScoreData={bestscore, coins}
    love.filesystem.write("data.txt", table.concat(ScoreData,"\n"))
end

function Xrange(x,target,margin,speed)
    return x < target+margin+speed and x > target-margin-speed
end

function Yrange(y,target,margin,speed)
    return y < target+margin+speed and y > target-margin-speed
end

function CheckCollision(x1,y1,w1,h1,x2,y2,w2,h2) --not mine
    return  x1 < x2+w2 and
            x2 < x1+w1 and
            y1 < y2+h2 and
            y2 < y1+h1
end